module NextOnRails
  class ActiveModelErrorsSerializer
    def initialize(model)
      @model = model
    end

    def serializable_hash
      i = -1
      full_messages = @model.errors.full_messages
      errors = @model.errors.messages.map do |field, error_messages|
        error_messages.map do |error_message|
          i += 1
          {
            title: error_message,
            detail: full_messages[i],
            attribute: field,
            source: { pointer: "/data/attributes/#{field}" }
          }
        end
      end
      @model.class.reflect_on_all_associations.each do |relationship|
        Array.wrap(@model.send(relationship.name)).each_with_index do |child, index|
          i = -1
          full_messages = @model.errors.full_messages
          errors << child.errors.messages.map do |field, error_messages|
            error_messages.map do |error_message|
              i += 1
              {
                title: error_message,
                detail: full_messages[i],
                attribute: "#{child.model_name.plural}[#{index}].#{field}",
                source: { pointer: "/data/attributes/#{child.model_name.plural}[#{index}].#{field}" }
              }
            end
          end
        end
      end
      return { errors: errors.flatten, hash_errors: @model.errors.as_json }
    end

    def to_json(options = nil)
      self.serializable_hash.to_json(options)
    end
  end
end
